nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Fc15I2cSda

Struct Fc15I2cSda 

#[repr(transparent)]
pub struct Fc15I2cSda(pub u32);
Special Registers (No GPIO Function)

Tuple Fields

0: u32

Implementations

Source

impl Fc15I2cSda

pub const fn fsel(&self) -> Fc15I2cSdaFsel

Function Selector. . .(FSELs Sources can be found in the next several pages.)

pub const fn set_fsel(&mut self, val: Fc15I2cSdaFsel)

Function Selector. . .(FSELs Sources can be found in the next several pages.)

pub const fn pupdena(&self) -> bool

Pullup / Pulldown Enable. . .

pub const fn set_pupdena(&mut self, val: bool)

Pullup / Pulldown Enable. . .

pub const fn pupdsel(&self) -> Fc15I2cSdaPupdsel

Pullup or Pulldown Selector. . .

pub const fn set_pupdsel(&mut self, val: Fc15I2cSdaPupdsel)

Pullup or Pulldown Selector. . .

pub const fn ibena(&self) -> bool

Input Buffer Enable. .

pub const fn set_ibena(&mut self, val: bool)

Input Buffer Enable. .

pub const fn slewrate(&self) -> Fc15I2cSdaSlewrate

Slew Rate Control. . .

pub const fn set_slewrate(&mut self, val: Fc15I2cSdaSlewrate)

Slew Rate Control. . .

pub const fn fulldrive(&self) -> Fc15I2cSdaFulldrive

Drive Selector. . .

pub const fn set_fulldrive(&mut self, val: Fc15I2cSdaFulldrive)

Drive Selector. . .

pub const fn amena(&self) -> bool

Analog Mux Enable. . .

pub const fn set_amena(&mut self, val: bool)

Analog Mux Enable. . .

pub const fn odena(&self) -> bool

Pseudo Output Drain Enable. . .

pub const fn set_odena(&mut self, val: bool)

Pseudo Output Drain Enable. . .

pub const fn iiena(&self) -> bool

Input Invert Enable. . .

pub const fn set_iiena(&mut self, val: bool)

Input Invert Enable. . .