nxp-pac

Crates

git

Versions

mimxrt685s_cm33

Flavors

Pio

Struct Pio 

#[repr(transparent)]
pub struct Pio(pub u32);
iop pad control register for port0 to port5

Tuple Fields

0: u32

Implementations

Source

impl Pio

pub const fn fsel(&self) -> Fsel

Function Selector. . .(FSELs Sources can be found in the next several pages.)

pub const fn set_fsel(&mut self, val: Fsel)

Function Selector. . .(FSELs Sources can be found in the next several pages.)

pub const fn pupdena(&self) -> bool

Pullup / Pulldown Enable. . .

pub const fn set_pupdena(&mut self, val: bool)

Pullup / Pulldown Enable. . .

pub const fn pupdsel(&self) -> Pupdsel

Pullup or Pulldown Selector. . .

pub const fn set_pupdsel(&mut self, val: Pupdsel)

Pullup or Pulldown Selector. . .

pub const fn ibena(&self) -> bool

Input Buffer Enable. .

pub const fn set_ibena(&mut self, val: bool)

Input Buffer Enable. .

pub const fn slewrate(&self) -> Slewrate

Slew Rate Control. . .

pub const fn set_slewrate(&mut self, val: Slewrate)

Slew Rate Control. . .

pub const fn fulldrive(&self) -> Fulldrive

Drive Selector. . .

pub const fn set_fulldrive(&mut self, val: Fulldrive)

Drive Selector. . .

pub const fn amena(&self) -> bool

Analog Mux Enable. . .

pub const fn set_amena(&mut self, val: bool)

Analog Mux Enable. . .

pub const fn odena(&self) -> bool

Pseudo Output Drain Enable. . .

pub const fn set_odena(&mut self, val: bool)

Pseudo Output Drain Enable. . .

pub const fn iiena(&self) -> bool

Input Invert Enable. . .

pub const fn set_iiena(&mut self, val: bool)

Input Invert Enable. . .