#[repr(transparent)]pub struct Fc15I2cScl(pub u32);Expand description
Special Registers (No GPIO Function)
Tuple Fields
0: u32Implementations
Sourceimpl Fc15I2cScl
impl Fc15I2cScl
Sourcepub const fn fsel(&self) -> Fc15I2cSclFsel
pub const fn fsel(&self) -> Fc15I2cSclFsel
Function Selector. . .(FSELs Sources can be found in the next several pages.)
Sourcepub const fn set_fsel(&mut self, val: Fc15I2cSclFsel)
pub const fn set_fsel(&mut self, val: Fc15I2cSclFsel)
Function Selector. . .(FSELs Sources can be found in the next several pages.)
Sourcepub const fn set_pupdena(&mut self, val: bool)
pub const fn set_pupdena(&mut self, val: bool)
Pullup / Pulldown Enable. . .
Sourcepub const fn pupdsel(&self) -> Fc15I2cSclPupdsel
pub const fn pupdsel(&self) -> Fc15I2cSclPupdsel
Pullup or Pulldown Selector. . .
Sourcepub const fn set_pupdsel(&mut self, val: Fc15I2cSclPupdsel)
pub const fn set_pupdsel(&mut self, val: Fc15I2cSclPupdsel)
Pullup or Pulldown Selector. . .
Sourcepub const fn slewrate(&self) -> Fc15I2cSclSlewrate
pub const fn slewrate(&self) -> Fc15I2cSclSlewrate
Slew Rate Control. . .
Sourcepub const fn set_slewrate(&mut self, val: Fc15I2cSclSlewrate)
pub const fn set_slewrate(&mut self, val: Fc15I2cSclSlewrate)
Slew Rate Control. . .
Sourcepub const fn fulldrive(&self) -> Fc15I2cSclFulldrive
pub const fn fulldrive(&self) -> Fc15I2cSclFulldrive
Drive Selector. . .
Sourcepub const fn set_fulldrive(&mut self, val: Fc15I2cSclFulldrive)
pub const fn set_fulldrive(&mut self, val: Fc15I2cSclFulldrive)
Drive Selector. . .