#[repr(transparent)]pub struct Fc15I2cSda(pub u32);Expand description
Special Registers (No GPIO Function)
Tuple Fields
0: u32Implementations
Sourceimpl Fc15I2cSda
impl Fc15I2cSda
Sourcepub const fn fsel(&self) -> Fc15I2cSdaFsel
pub const fn fsel(&self) -> Fc15I2cSdaFsel
Function Selector. . .(FSELs Sources can be found in the next several pages.)
Sourcepub const fn set_fsel(&mut self, val: Fc15I2cSdaFsel)
pub const fn set_fsel(&mut self, val: Fc15I2cSdaFsel)
Function Selector. . .(FSELs Sources can be found in the next several pages.)
Sourcepub const fn set_pupdena(&mut self, val: bool)
pub const fn set_pupdena(&mut self, val: bool)
Pullup / Pulldown Enable. . .
Sourcepub const fn pupdsel(&self) -> Fc15I2cSdaPupdsel
pub const fn pupdsel(&self) -> Fc15I2cSdaPupdsel
Pullup or Pulldown Selector. . .
Sourcepub const fn set_pupdsel(&mut self, val: Fc15I2cSdaPupdsel)
pub const fn set_pupdsel(&mut self, val: Fc15I2cSdaPupdsel)
Pullup or Pulldown Selector. . .
Sourcepub const fn slewrate(&self) -> Fc15I2cSdaSlewrate
pub const fn slewrate(&self) -> Fc15I2cSdaSlewrate
Slew Rate Control. . .
Sourcepub const fn set_slewrate(&mut self, val: Fc15I2cSdaSlewrate)
pub const fn set_slewrate(&mut self, val: Fc15I2cSdaSlewrate)
Slew Rate Control. . .
Sourcepub const fn fulldrive(&self) -> Fc15I2cSdaFulldrive
pub const fn fulldrive(&self) -> Fc15I2cSdaFulldrive
Drive Selector. . .
Sourcepub const fn set_fulldrive(&mut self, val: Fc15I2cSdaFulldrive)
pub const fn set_fulldrive(&mut self, val: Fc15I2cSdaFulldrive)
Drive Selector. . .