#[repr(transparent)]pub struct Pio(pub u32);Expand description
iop pad control register for port0 to port5
Tuple Fields
0: u32Implementations
Sourceimpl Pio
impl Pio
Sourcepub const fn fsel(&self) -> Fsel
pub const fn fsel(&self) -> Fsel
Function Selector. . .(FSELs Sources can be found in the next several pages.)
Sourcepub const fn set_fsel(&mut self, val: Fsel)
pub const fn set_fsel(&mut self, val: Fsel)
Function Selector. . .(FSELs Sources can be found in the next several pages.)
Sourcepub const fn set_pupdena(&mut self, val: bool)
pub const fn set_pupdena(&mut self, val: bool)
Pullup / Pulldown Enable. . .
Sourcepub const fn set_pupdsel(&mut self, val: Pupdsel)
pub const fn set_pupdsel(&mut self, val: Pupdsel)
Pullup or Pulldown Selector. . .
Sourcepub const fn set_slewrate(&mut self, val: Slewrate)
pub const fn set_slewrate(&mut self, val: Slewrate)
Slew Rate Control. . .
Sourcepub const fn set_fulldrive(&mut self, val: Fulldrive)
pub const fn set_fulldrive(&mut self, val: Fulldrive)
Drive Selector. . .